# Basis Functions

Basis functions control how smooth terms behave in your GAM models. Different basis types are suitable for different kinds of data and modeling requirements:

::: pymgcv.basis_functions.ThinPlateSpline
::: pymgcv.basis_functions.CubicSpline
::: pymgcv.basis_functions.BSpline
::: pymgcv.basis_functions.PSpline
::: pymgcv.basis_functions.DuchonSpline
::: pymgcv.basis_functions.SplineOnSphere
::: pymgcv.basis_functions.RandomEffect
::: pymgcv.basis_functions.MarkovRandomField
::: pymgcv.basis_functions.RandomWigglyCurve
::: pymgcv.basis_functions.BasisLike
